TODO
====

- Improve test coverage of original import checker module.

- Try it on more projects and gather feedback.

- Try to handle local (so non-absolute) imports.

- Display impacted files for each section (like Unused imports). Maybe with a
  option (-v)?

- Improve documentation on commandline usage ("you can pass a
  directoryname").
